@@ -1,3 +1,10 @@
+
+/*
+ * Copyright (C) Xiaozhe Wang (chaoslawful)
+ * Copyright (C) Yichun Zhang (agentzh)
+ */
+
+
 #ifndef DDEBUG
 #define DDEBUG 0
 #endif
@@ -59,7 +66,7 @@ ngx_http_lua_ngx_exec(lua_State *L)
     n = lua_gettop(L);
     if (n != 1 && n != 2) {
         return luaL_error(L, "expecting one or two arguments, but got %d",
-                n);
+                          n);
     }
 
     lua_pushlightuserdata(L, &ngx_http_lua_request_key);
@@ -142,7 +149,7 @@ ngx_http_lua_ngx_exec(lua_State *L)
 
         default:
             msg = lua_pushfstring(L, "string, number, or table expected, "
-                    "but got %s", luaL_typename(L, 2));
+                                  "but got %s", luaL_typename(L, 2));
             return luaL_argerror(L, 2, msg);
         }
 
@@ -154,6 +161,7 @@ ngx_http_lua_ngx_exec(lua_State *L)
     if (user_args.len) {
         if (args.len == 0) {
             args = user_args;
+
         } else {
             p = ngx_palloc(r->pool, args.len + user_args.len + 1);
             if (p == NULL) {
@@ -171,7 +179,7 @@ ngx_http_lua_ngx_exec(lua_State *L)
 
     if (ctx->headers_sent) {
         return luaL_error(L, "attempt to call ngx.exec after "
-                "sending out response headers");
+                          "sending out response headers");
     }
 
     ctx->exec_uri = uri;
@@ -211,7 +219,7 @@ ngx_http_lua_ngx_redirect(lua_State *L)
                 rc != NGX_HTTP_MOVED_PERMANENTLY)
         {
             return luaL_error(L, "only ngx.HTTP_MOVED_TEMPORARILY and "
-                    "ngx.HTTP_MOVED_PERMANENTLY are allowed");
+                              "ngx.HTTP_MOVED_PERMANENTLY are allowed");
         }
     } else {
         rc = NGX_HTTP_MOVED_TEMPORARILY;
@@ -239,7 +247,7 @@ ngx_http_lua_ngx_redirect(lua_State *L)
 
     if (ctx->headers_sent) {
         return luaL_error(L, "attempt to call ngx.redirect after sending out "
-                "the headers");
+                          "the headers");
     }
 
     uri = ngx_palloc(r->pool, len);
@@ -256,7 +264,7 @@ ngx_http_lua_ngx_redirect(lua_State *L)
 
     r->headers_out.location->hash =
             ngx_hash(ngx_hash(ngx_hash(ngx_hash(ngx_hash(ngx_hash(
-                    ngx_hash('l', 'o'), 'c'), 'a'), 't'), 'i'), 'o'), 'n');
+                     ngx_hash('l', 'o'), 'c'), 'a'), 't'), 'i'), 'o'), 'n');
 
 #if 0
     dd("location hash: %lu == %lu",
@@ -309,7 +317,8 @@ ngx_http_lua_ngx_exit(lua_State *L)
 
     ngx_http_lua_check_context(L, ctx, NGX_HTTP_LUA_CONTEXT_REWRITE
                                | NGX_HTTP_LUA_CONTEXT_ACCESS
-                               | NGX_HTTP_LUA_CONTEXT_CONTENT);
+                               | NGX_HTTP_LUA_CONTEXT_CONTENT
+                               | NGX_HTTP_LUA_CONTEXT_TIMER);
 
     rc = (ngx_int_t) luaL_checkinteger(L, 1);
 
@@ -370,6 +379,8 @@ ngx_http_lua_on_abort(lua_State *L)
         return luaL_error(L, "no request ctx found");
     }
 
+    ngx_http_lua_check_fake_request2(L, r, ctx);
+
     if (ctx->on_abort_co_ctx) {
         lua_pushnil(L);
         lua_pushliteral(L, "duplicate call");
@@ -406,3 +417,4 @@ ngx_http_lua_on_abort(lua_State *L)
     return 1;
 }
 
+/* vi:set ft=c ts=4 sw=4 et fdm=marker: */
