@@ -1,11 +1,15 @@
-/* vim:set ft=c ts=4 sw=4 et fdm=marker: */
-/* Copyright (C) agentzh */
+
+/*
+ * Copyright (C) Yichun Zhang (agentzh)
+ */
+
 
 #ifndef DDEBUG
 #define DDEBUG 0
 #endif
 #include "ddebug.h"
 
+
 #include <nginx.h>
 #include "ngx_http_lua_headers_in.h"
 #include "ngx_http_lua_util.h"
@@ -16,8 +20,7 @@ static ngx_int_t ngx_http_set_header(ngx_http_request_t *r,
     ngx_http_lua_header_val_t *hv, ngx_str_t *value);
 static ngx_int_t ngx_http_set_header_helper(ngx_http_request_t *r,
     ngx_http_lua_header_val_t *hv, ngx_str_t *value,
-    ngx_table_elt_t **output_header,
-    unsigned no_create);
+    ngx_table_elt_t **output_header, unsigned no_create);
 static ngx_int_t ngx_http_set_builtin_header(ngx_http_request_t *r,
     ngx_http_lua_header_val_t *hv, ngx_str_t *value);
 static ngx_int_t ngx_http_set_content_length_header(ngx_http_request_t *r,
@@ -25,14 +28,14 @@ static ngx_int_t ngx_http_set_content_length_header(ngx_http_request_t *r,
 static ngx_int_t ngx_http_clear_builtin_header(ngx_http_request_t *r,
     ngx_http_lua_header_val_t *hv, ngx_str_t *value);
 static ngx_int_t ngx_http_clear_content_length_header(ngx_http_request_t *r,
-        ngx_http_lua_header_val_t *hv, ngx_str_t *value);
+    ngx_http_lua_header_val_t *hv, ngx_str_t *value);
 static ngx_int_t ngx_http_set_host_header(ngx_http_request_t *r,
-        ngx_http_lua_header_val_t *hv, ngx_str_t *value);
+    ngx_http_lua_header_val_t *hv, ngx_str_t *value);
 static ngx_int_t ngx_http_lua_rm_header_helper(ngx_list_t *l,
-        ngx_list_part_t *cur, ngx_uint_t i);
+    ngx_list_part_t *cur, ngx_uint_t i);
 
 
-static ngx_http_lua_set_header_t ngx_http_lua_set_handlers[] = {
+static ngx_http_lua_set_header_t  ngx_http_lua_set_handlers[] = {
 
 #if (NGX_HTTP_GZIP)
     { ngx_string("Accept-Encoding"),
@@ -100,7 +103,7 @@ static ngx_http_lua_set_header_t ngx_http_lua_set_handlers[] = {
 
 static ngx_int_t
 ngx_http_set_header(ngx_http_request_t *r, ngx_http_lua_header_val_t *hv,
-        ngx_str_t *value)
+    ngx_str_t *value)
 {
     return ngx_http_set_header_helper(r, hv, value, NULL, 0);
 }
@@ -108,8 +111,8 @@ ngx_http_set_header(ngx_http_request_t *r, ngx_http_lua_header_val_t *hv,
 
 static ngx_int_t
 ngx_http_set_header_helper(ngx_http_request_t *r, ngx_http_lua_header_val_t *hv,
-        ngx_str_t *value, ngx_table_elt_t **output_header,
-        unsigned no_create)
+    ngx_str_t *value, ngx_table_elt_t **output_header,
+    unsigned no_create)
 {
     ngx_table_elt_t             *h;
     ngx_list_part_t             *part;
@@ -138,15 +141,14 @@ retry:
         dd("i: %d, part: %p", (int) i, part);
 
         if (h[i].key.len == hv->key.len
-                && ngx_strncasecmp(h[i].key.data,
-                    hv->key.data,
-                    h[i].key.len) == 0)
+            && ngx_strncasecmp(h[i].key.data, hv->key.data, h[i].key.len)
+               == 0)
         {
             if (value->len == 0) {
                 h[i].hash = 0;
 
-                rc = ngx_http_lua_rm_header_helper(
-                        &r->headers_in.headers, part, i);
+                rc = ngx_http_lua_rm_header_helper(&r->headers_in.headers,
+                                                   part, i);
 
                 if (rc == NGX_OK) {
                     if (output_header) {
@@ -213,7 +215,7 @@ new_header:
 
 static ngx_int_t
 ngx_http_set_builtin_header(ngx_http_request_t *r,
-        ngx_http_lua_header_val_t *hv, ngx_str_t *value)
+    ngx_http_lua_header_val_t *hv, ngx_str_t *value)
 {
     ngx_table_elt_t             *h, **old;
 
@@ -254,7 +256,7 @@ ngx_http_set_builtin_header(ngx_http_request_t *r,
 
 static ngx_int_t
 ngx_http_set_host_header(ngx_http_request_t *r, ngx_http_lua_header_val_t *hv,
-        ngx_str_t *value)
+    ngx_str_t *value)
 {
     dd("server new value len: %d", (int) value->len);
 
@@ -266,7 +268,7 @@ ngx_http_set_host_header(ngx_http_request_t *r, ngx_http_lua_header_val_t *hv,
 
 static ngx_int_t
 ngx_http_set_content_length_header(ngx_http_request_t *r,
-        ngx_http_lua_header_val_t *hv, ngx_str_t *value)
+    ngx_http_lua_header_val_t *hv, ngx_str_t *value)
 {
     off_t           len;
 
@@ -289,7 +291,7 @@ ngx_http_set_content_length_header(ngx_http_request_t *r,
 
 static ngx_int_t
 ngx_http_clear_content_length_header(ngx_http_request_t *r,
-        ngx_http_lua_header_val_t *hv, ngx_str_t *value)
+    ngx_http_lua_header_val_t *hv, ngx_str_t *value)
 {
     r->headers_in.content_length_n = -1;
 
@@ -299,7 +301,7 @@ ngx_http_clear_content_length_header(ngx_http_request_t *r,
 
 static ngx_int_t
 ngx_http_clear_builtin_header(ngx_http_request_t *r,
-        ngx_http_lua_header_val_t *hv, ngx_str_t *value)
+    ngx_http_lua_header_val_t *hv, ngx_str_t *value)
 {
     value->len = 0;
     return ngx_http_set_builtin_header(r, hv, value);
@@ -308,7 +310,7 @@ ngx_http_clear_builtin_header(ngx_http_request_t *r,
 
 ngx_int_t
 ngx_http_lua_set_input_header(ngx_http_request_t *r, ngx_str_t key,
-        ngx_str_t value, unsigned override)
+    ngx_str_t value, unsigned override)
 {
     ngx_http_lua_header_val_t         hv;
     ngx_http_lua_set_header_t        *handlers = ngx_http_lua_set_handlers;
@@ -326,11 +328,11 @@ ngx_http_lua_set_input_header(ngx_http_request_t *r, ngx_str_t key,
 
     for (i = 0; handlers[i].name.len; i++) {
         if (hv.key.len != handlers[i].name.len
-                || ngx_strncasecmp(hv.key.data, handlers[i].name.data,
-                    handlers[i].name.len) != 0)
+            || ngx_strncasecmp(hv.key.data, handlers[i].name.data,
+                               handlers[i].name.len) != 0)
         {
             dd("hv key comparison: %s <> %s", handlers[i].name.data,
-                    hv.key.data);
+               hv.key.data);
 
             continue;
         }
@@ -360,21 +362,21 @@ ngx_http_lua_set_input_header(ngx_http_request_t *r, ngx_str_t key,
 
 static ngx_int_t
 ngx_http_lua_rm_header_helper(ngx_list_t *l, ngx_list_part_t *cur,
-        ngx_uint_t i)
+    ngx_uint_t i)
 {
     ngx_table_elt_t             *data;
     ngx_list_part_t             *new, *part;
 
     dd("list rm item: part %p, i %d, nalloc %d", cur, (int) i,
-            (int) l->nalloc);
+       (int) l->nalloc);
 
     data = cur->elts;
 
     dd("cur: nelts %d, nalloc %d", (int) cur->nelts,
-            (int) l->nalloc);
+       (int) l->nalloc);
 
     dd("removing: \"%.*s:%.*s\"", (int) data[i].key.len, data[i].key.data,
-            (int) data[i].value.len, data[i].value.data);
+       (int) data[i].value.len, data[i].value.data);
 
     if (i == 0) {
         cur->elts = (char *) cur->elts + l->size;
@@ -454,3 +456,4 @@ ngx_http_lua_rm_header_helper(ngx_list_t *l, ngx_list_part_t *cur,
     return NGX_OK;
 }
 
+/* vi:set ft=c ts=4 sw=4 et fdm=marker: */
